<?php
/*
 Newswriter v2.56
 PHP News Management System
 Copyright (C) 2000-2002 Philipp Wolfer

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the license, or
 (at your option) any later version.
 See license.txt for further information.

 editfunc.inc.php, last change: 01.09.2002

 These functions are only required if Newswriter runs in edit-mode:
  * prepare_text(string text)      (line 31)
  * bbcode2html(string text)       (line 83)
  * html2bbcode(string text)       (line 108)
  * strip_quots(string text)       (line 125)
  * add_quots(string text)         (line 130)
  * link_url(string text)          (line 136)
  * send_infomail()                (line 160)
  * show_edit()                    (line 200)
*/

include($NWCONF_SYSTEM['server_path'].'include/javascript.inc'.$NWCONF_SYSTEM['php_ext']);
require($NWCONF_SYSTEM['server_path'].'include/text-out.inc'.$NWCONF_SYSTEM['php_ext']);
require($NWCONF_SYSTEM['server_path'].'include/images.inc'.$NWCONF_SYSTEM['php_ext']);

// Prepare texts for output inside form tags:
function prepare_text($string)
{
  global $NWCONF_INTERFACE, $NW_INFO, $NW_RUNTIME;

  $string = stripslashes($string);
  if ($NWCONF_INTERFACE['auto_br']) {
    $string = preg_replace("#<br( /)?>#i", "\n", $string);
  }
  else {
    $saved_tags[0] = "<br />\n";
//    $string = str_replace('<br />', '####0####', $string);
    $string =  preg_replace("#<br( /)?>#i", '####0####', $string);
  }

  if ($NW_RUNTIME['allow_html']) {
    $i = 1;
    while (preg_match('#<[^?%!][^>]*>#', $string, $tag)) {
      $saved_tags[$i] = str_replace("\r\n", "", $tag[0]);
      $saved_tags[$i] = str_replace("\n", "", $saved_tags[$i]);
      $string = str_replace($tag[0],'####'.$i.'####', $string);
      $i++;
    }
  }
  else {
    $string = str_replace('<', '&lt;', $string);
    $string = str_replace('>', '&gt;', $string);
  }

  if ($NW_INFO['phpversion'] >= '4.0.0') {
    $trans = get_html_translation_table(HTML_ENTITIES);
    $string = strtr($string, array_flip($trans));
    $string = strtr($string, $trans);
  }
  else {
    $string = str_replace('"', '&quot;', $string);
  }

  if ($NWCONF_INTERFACE['auto_br']) {
    $string = str_replace("\r\n","<br />",$string);
    $string = str_replace("\n","<br />",$string);
  }
  else {
    $string = str_replace("\r\n"," ",$string);
    $string = str_replace("\n"," ",$string);
  }
  if (is_array($saved_tags)) {
    while (list($i,$tag) = each($saved_tags)) {
      $string = str_replace('####'.$i.'####',$tag,$string);
    }
  }
  return $string;
}

function bbcode2html($string) {
  $string = preg_replace("#<br( )?>#i", "<br />", $string);
  $string = preg_replace("#\[b\](.*?)\[/b\]#i","<b>\\1</b>", $string);
  $string = preg_replace("#\[i\](.*?)\[/i\]#i","<i>\\1</i>", $string);
  $string = preg_replace("#\[code\](<br />)?(.*?)(<br />)?\[/code\]#i","<pre>\\2</pre>", $string);
  while (preg_match('#(<br />)?\[list(=(a|1))?\].*?\[/list\](<br />)?#i', $string, $tag)) {
    if ($tag[2] == '=1')
      $replacement = preg_replace("#^(<br />)?\[list=1\](<br />)?#i", '<ol start="1" type="1">', $tag[0]);
    elseif ($tag[2] == '=A' || $tag[2] == '=a')
      $replacement = preg_replace("#^(<br />)?\[list=a\](<br />)?#i", '<ol start="1" type="A">', $tag[0]);
    else
      $replacement = preg_replace("#^(<br />)?\[list\](<br />)?#i", "<ul>", $tag[0]);
    if ($tag[2] == '=1' || $tag[2] == '=A' || $tag[2] == '=a')
      $replacement = preg_replace("#(<br />)?\[/list\](<br />)?$#i", "</ol>", $replacement);
    else
      $replacement = preg_replace("#(<br />)?\[/list\](<br />)?$#i", "</ul>", $replacement);
    $replacement = preg_replace('#(<br />)?\[\*\]#', '<li>', $replacement);
    $string = str_replace($tag[0], $replacement, $string);
  }
  $string = preg_replace("#\[img\]http://([^]]+)\[/img\]#i", '<!--BBCODE//--><img src="http://\\1" border="0">', $string);
  $string = preg_replace("#\[url\](\w+)://([^]]+)\[/url\]#i", '<!--BBCODE//--><a href="\\1://\\2" target="_blank">\\1://\\2</a>', $string);
  $string = preg_replace("#\[url=(\w+)://([^]]+)\](.*?)\[/url\]#i", '<!--BBCODE//--><a href="\\1://\\2" target="_blank">\\3</a>', $string);
  $string = preg_replace("#\[email\]([\w~.]+?@[\w~.]+?)\[/email\]#i", '<!--BBCODE//--><a href="mailto:\\1">\\1</a>', $string);
  return $string;
}

function html2bbcode($string) {
  $string = preg_replace("#<b>(.*?)</b>#i","[B]\\1[/B]",$string);
  $string = preg_replace("#<i>(.*?)</i>#i","[I]\\1[/I]",$string);
  $string = preg_replace("#<pre>(.*?)</pre>#i","[CODE]\n\\1\n[/CODE]",$string);
  $string = str_replace("<ul>","\n[LIST]",$string);
  $string = str_replace("</ul>","\n[/LIST]\n",$string);
  $string = str_replace('<ol start="1" type="1">',"\n[LIST=1]",$string);
  $string = str_replace('<ol start="1" type="A">',"\n[LIST=A]",$string);
  $string = str_replace("</ol>","\n[/LIST]\n",$string);
  $string = str_replace("<li>","\n[*]",$string);
  $string = preg_replace('#<!--BBCODE//--><img src="http://([^"]+)"[^>]*>#i', '[IMG]http://\\1[/IMG]', $string);
  $string = preg_replace('#<!--BBCODE//--><a href="mailto:([^"]*)">[^>]*</a>#i', '[EMAIL]\\1[/EMAIL]', $string);
  $string = preg_replace('#<!--BBCODE//--><a href="([^"]*)"([^:]*)://([^>]*)</a>#i', '[URL]\\1[/URL]', $string);
  $string = preg_replace('#<!--BBCODE//--><a href="([^"]*)"([^>]*)>([^>]*)</a>#i', '[URL=\\1]\\3[/URL]', $string);
  return $string;
}

function strip_quots($string) {
  $string = str_replace('"','####QUOT####',$string);
  return $string;
}

function add_quots($string) {
  $string = str_replace('####QUOT####','"',$string);
  return $string;
}

// URLs verlinken:
function link_url($text)
{
  $i = 0;
  while (preg_match('#<a[^>]*>.*?</a>#',$text,$tag)) {
    $saved_tags[$i] = $tag[0];
    $text = str_replace($tag[0],'####'.$i.'####',$text);
    $i++;
  }
  while (preg_match('#<img[^>]*>#',$text,$tag)) {
    $saved_tags[$i] = $tag[0];
    $text = str_replace($tag[0],'####'.$i.'####',$text);
    $i++;
  }
  $text = preg_replace('|\b(\w+://[\w#?/&=~.-]+)(####\d+####)?\b|', "<a href=\"\\1\" target=\"_blank\">\\1</a>", $text);
  $text = preg_replace('|\b([a-z0-9\-_.]+?)@([\w\-]+\.([\w\-\.]+\.)?[\w]+)(####\d+####)?\b|i', "<a href=\"mailto:\\1@\\2\">\\1@\\2</a>", $text);
  if (is_array($saved_tags)) {
    while (list($i,$tag) = each($saved_tags)) {
      $text = str_replace('####'.$i.'####',$tag,$text);
    }
  }
  return $text;
}

// Benachrichtigungsmail an Admin schicken:
function send_infomail()
{
  global $NW_FORMDATA, $NW_RUNTIME, $NW_TRANSLATION, $NWCONF_SYSTEM, $NWCONF_USERS, $NW_INFO;
  global $HTTP_SERVER_VARS;

  $mail_tpl = file($NWCONF_SYSTEM['server_path'].$NWCONF_SYSTEM['template_dir'].'admin/infomail.tpl');

  $subject = str_replace('SUBJECT=','',$mail_tpl[0]);
  $archiv_url = $NWCONF_SYSTEM['index_file'].'?nwaction=shownews&nwmode=archiv&newsmonth='.strftime('%Y%m', $NW_RUNTIME['act_timestamp']).'#'.$NW_RUNTIME['act_timestamp'];

  if ($HTTP_SERVER_VARS['SERVER_URL'])
    $link = rmv_slash($HTTP_SERVER_VARS['SERVER_URL']).str_replace($HTTP_SERVER_VARS['SERVER_URL'],'/',$NWCONF_SYSTEM['domain_path']).$archiv_url;
  elseif ($HTTP_SERVER_VARS['SERVER_NAME'])
    $link = 'http://'.rmv_slash($HTTP_SERVER_VARS['SERVER_NAME']).str_replace('http://'.$HTTP_SERVER_VARS['SERVER_NAME'],'',$NWCONF_SYSTEM['domain_path']).$archiv_url;

  $key = 1;
  while ($mail_tpl[$key]) {
    $message .= $mail_tpl[$key++];
  }
  $msgtext = preg_replace("#<br[^>]*>#i", "\n", $NW_FORMDATA['news_text']);
  $msgtext = strip_tags($msgtext);
  if ($NW_INFO['phpversion'] >= '4.0.0') {
    $trans = get_html_translation_table(HTML_ENTITIES);
    $msgtext = strtr($msgtext, array_flip($trans));
  }
  
  $message = str_replace('[--AUTHOR--]',$NW_FORMDATA['news_name'],$message);
  $message = str_replace('[--DATE--]',$NW_FORMDATA['news_date'],$message);
  $message = str_replace('[--LINK--]',$link,$message);
	$message = str_replace('[--TOPIC--]',$NW_FORMDATA['news_topic'],$message);
	$message = str_replace('[--SUBTOPIC--]',$NW_FORMDATA['news_subtopic'],$message);
	$message = str_replace('[--TITLE--]',$NW_FORMDATA['news_title'],$message);
  $message = str_replace('[--TEXT--]',$msgtext,$message);

  reset($NWCONF_USERS['admins']);
  while (list($key,$name) = each($NWCONF_USERS['admins'])) {
    if ($NW_RUNTIME['nwlogin'] != $name && $NWCONF_USERS['email'][$name]) {
      if (!mail($NWCONF_USERS['email'][$name], $subject, $message))
        echo '<p>'.$NW_TRANSLATION['error_sendreport'].'</p>';
     // else
      //  echo '<p>Notification mail sent to '.$NWCONF_USERS['email'][$name].'</p>';
    }
  }
  reset($NWCONF_USERS['admins']);
}

// Edit-Bereich anzeigen:
function show_edit()
{
  global $NW_FORMDATA, $NW_RUNTIME, $NWCONF_SYSTEM, $NWCONF_DISPLAY, $NWCONF_INTERFACE, $NWCONF_USERS, $NW_TRANSLATION, $NW_MESSAGES;
  global $HTTP_POST_FILES, $HTTP_POST_VARS;

  $NW_FORMDATA = $HTTP_POST_VARS;
  if (isset($HTTP_POST_FILES['userimg']))
    $userimg_name = $HTTP_POST_FILES['userimg']['name'];
  elseif (isset($HTTP_POST_VARS['userimg']))
    $userimg_name = $HTTP_POST_VARS['userimg']['name'];

  if ($NWCONF_INTERFACE['allow_html'] && $NW_FORMDATA['allow_html'] == 'true')
    $NW_RUNTIME['allow_html'] = true;
  else
    $NW_RUNTIME['allow_html'] = false;

  if ($NW_RUNTIME['nwaction'] == 'delnews' && $NW_FORMDATA['delconfirm'] != 'true') {
    $NW_RUNTIME['nwmode'] = 'edit';
    $NW_RUNTIME['nwaction'] = 'edit';
  }

  if ($NWCONF_INTERFACE['allow_html'] && is_array($NWCONF_INTERFACE['easy_tags'])) {
    while (list($key,$name) = each ($NWCONF_INTERFACE['easy_tags'])) {
      $NWCONF_INTERFACE['easy_tags'][$key] = str_replace('"','&quot;',$name);
    }
    reset($NWCONF_INTERFACE['easy_tags']);
  }

  if ($NW_RUNTIME['nwaction'] == 'edit' && !$NW_FORMDATA['file_name'])
    $NW_RUNTIME['nwaction'] = 'shownews';

  if ($NW_RUNTIME['nwaction'] == 'new' || $NW_RUNTIME['nwaction'] == 'edit') {
    if ($NW_FORMDATA['file_name'] && (!$NW_FORMDATA['nweditstep'] || $NW_FORMDATA['nweditstep'] < 2)) {
      $file_entries = get_filedata($NW_FORMDATA['file_name']);
      $NW_FORMDATA['news_topic'] = $file_entries['TOPIC'];
      $NW_FORMDATA['news_subtopic'] = $file_entries['SUBTOPIC'];
      $NW_FORMDATA['news_title'] = $file_entries['TITLE'];
      $NW_FORMDATA['news_name'] = $file_entries['NAME'];
      $NW_FORMDATA['news_email'] = $file_entries['EMAIL'];
      $NW_FORMDATA['news_nwurl'] = $file_entries['URL'];
      $NW_FORMDATA['news_date'] = $file_entries['DATE'];
      if ($file_entries['STARTDATE']) {
        $NW_FORMDATA['news_startdate'] = true;
        $NW_FORMDATA['startdate_day'] = strftime('%d',$file_entries['STARTDATE']);
        $NW_FORMDATA['startdate_month'] = strftime('%m',$file_entries['STARTDATE']);
        $NW_FORMDATA['startdate_year'] = strftime('%Y',$file_entries['STARTDATE']);
      }
      if ($file_entries['EXPIRE']) {
        $NW_FORMDATA['news_expire'] = true;
        $NW_FORMDATA['expiredate_day'] = strftime('%d',$file_entries['EXPIRE']);
        $NW_FORMDATA['expiredate_month'] = strftime('%m',$file_entries['EXPIRE']);
        $NW_FORMDATA['expiredate_year'] = strftime('%Y',$file_entries['EXPIRE']);
      }
      if ($file_entries['LINK']) {
        $NW_FORMDATA['news_url'] = preg_replace('#<a href="([^"]*)".+?</a>#i','\\1',$file_entries['LINK']);
        $NW_FORMDATA['news_lname'] = preg_replace('#<[^>]*>#','',$file_entries['LINK']);
        if (strstr($file_entries['LINK'],'target="_blank"'))
          $NW_FORMDATA['news_lopenwin'] = true;
        $NW_FORMDATA['news_link'] = true;
      }
      else {
        $NW_FORMDATA['news_lopenwin'] = true;
      }
      if ($file_entries['IMAGE1']) {
        $NW_FORMDATA['news_img1'] = true;
        list($NW_FORMDATA['img1_url'], $NW_FORMDATA['img1_align']) = explode ('***',$file_entries['IMAGE1']);
      }
      if ($file_entries['ARTICLE']) {
        $NW_FORMDATA['afile_name'] = $file_entries['ARTICLE'];
        if ($file_entries['IMAGE2']) {
          $NW_FORMDATA['news_img2'] = true;
          list($NW_FORMDATA['img2_url'], $NW_FORMDATA['img2_align']) = explode ('***',$file_entries['IMAGE2']);
          if ($file_entries['IMAGE2TEXT'])
            $NW_FORMDATA['img2_text'] = $file_entries['IMAGE2TEXT'];
        }
      }
      $NW_FORMDATA['news_text'] = $file_entries['TEXT'];
      if ($NWCONF_INTERFACE['allow_bbcode'])
        $NW_FORMDATA['news_text'] = html2bbcode($NW_FORMDATA['news_text']);
      if ($NWCONF_INTERFACE['make_links'])
        $NW_FORMDATA['news_text'] = preg_replace('#<a href=[^>]*>(\w+)://(.+?)</a>#i','\\1://\\2',$NW_FORMDATA['news_text']);
    }
    if (!$NW_FORMDATA['news_name'])
      $NW_FORMDATA['news_name'] = $NWCONF_USERS['realname'][$NW_RUNTIME['nwlogin']];
    if ($NW_RUNTIME['nwaction'] != 'edit') {
      if (!$NW_FORMDATA['news_email'])
        $NW_FORMDATA['news_email'] = $NWCONF_USERS['email'][get_loginname($NW_FORMDATA['news_name'])];
      if (!$NW_FORMDATA['news_nwurl'])
        $NW_FORMDATA['news_nwurl'] = $NWCONF_USERS['home'][get_loginname($NW_FORMDATA['news_name'])];
    }
    if (!$NW_FORMDATA['news_lname'])
      $NW_FORMDATA['news_lname'] = 'link';
    if (!$NW_FORMDATA['news_url'])
      $NW_FORMDATA['news_url'] = 'http://';
    if (!$error_msg && $NW_RUNTIME['nwaction'] == 'new' && isset($NW_FORMDATA['news_lopenwin']))
      $NW_FORMDATA['news_lopenwin'] = true;

    if (($NW_RUNTIME['nwaction'] == 'edit' && ($NWCONF_USERS['realname'][$NW_RUNTIME['nwlogin']] == $NW_FORMDATA['news_name'] || $NW_RUNTIME['admin_mode'])) || $NW_RUNTIME['nwaction'] == 'new') {
      if (!$NW_FORMDATA['nweditstep'])
        $NW_FORMDATA['nweditstep'] = 1;
      if ($NW_FORMDATA['nweditstep'] == 3 && !$NWCONF_INTERFACE['allow_images'])
        $nwedit_step = 4;

     /* Creating error messages for each step: */
      if ($NW_FORMDATA['nweditstep'] == 2 && (!$NW_FORMDATA['news_title'] || !$NW_FORMDATA['news_text'] || (strlen($NW_FORMDATA['news_text']) > $NWCONF_INTERFACE['max_text_length'] && $NWCONF_INTERFACE['max_text_length'] > 0))) {
        $error_msg = '<p>'.$NW_TRANSLATION['edit_error'].'</p><ul type="square">';
        if (!$NW_FORMDATA['news_title'])
          $error_msg .= '<li>'.$NW_TRANSLATION['edit_error_title'].'</li>';
        if (!$NW_FORMDATA['news_text'])
          $error_msg .= '<li>'.$NW_TRANSLATION['edit_error_text'].'</li>';
        if (strlen($NW_FORMDATA['news_text']) > $NWCONF_INTERFACE['max_text_length'] && $NWCONF_INTERFACE['max_text_length'] > 0)
          $error_msg .= '<li>'.$NW_TRANSLATION['edit_error_toolong1'].$NWCONF_INTERFACE['max_text_length'].$NW_TRANSLATION['edit_error_toolong2'].'</li>';
        $error_msg .= '</ul>';
        $NW_FORMDATA['nweditstep'] = 1;
      }
      elseif ($NW_FORMDATA['nweditstep'] == 3 && ($NW_FORMDATA['news_article'] && !$NW_FORMDATA['news_atext'])) {
        $error_msg = '<p>'.$NW_TRANSLATION['edit_error'].'</p><ul type="square">';
        $error_msg .= '<li>'.$NW_TRANSLATION['edit_error_articletext'].'</li>';
        $error_msg .= '</ul>';
        $NW_FORMDATA['nweditstep'] = 2;
      }
      elseif ($NW_FORMDATA['nweditstep'] == 4 && (($NW_FORMDATA['news_img1'] && !$NW_FORMDATA['img1_url']) || ($NW_FORMDATA['news_img2'] && !$NW_FORMDATA['img2_url']))) {
        $error_msg = '<p>'.$NW_TRANSLATION['edit_error'].'</p><ul type="square">';
        if ($NW_FORMDATA['news_img1'] && !$NW_FORMDATA['img1_url'])
          $error_msg .= '<li>'.$NW_TRANSLATION['edit_error_picture1url'].'</li>';
        if ($NW_FORMDATA['news_img2'] && !$NW_FORMDATA['img2_url'])
          $error_msg .= '<li>'.$NW_TRANSLATION['edit_error_picture2url'].'</li>';
        $error_msg .= '</ul>';
        $NW_FORMDATA['nweditstep'] = 3;
      }
      elseif ($NW_FORMDATA['nweditstep'] == 5
              && (
                ($NW_FORMDATA['news_expire']
                && (
                  !$NW_FORMDATA['expiredate_day']
                  || !$NW_FORMDATA['expiredate_month']
                  || !$NW_FORMDATA['expiredate_year']))
                || ($NW_FORMDATA['news_startdate']
                && (
                    !$NW_FORMDATA['startdate_day']
                    || !$NW_FORMDATA['startdate_month']
                    || !$NW_FORMDATA['startdate_year']))
                || ($NW_FORMDATA['news_expire']
                && (
                  !$NW_FORMDATA['expiredate_day']
                  || !$NW_FORMDATA['expiredate_month']
                  || !$NW_FORMDATA['expiredate_year']))
                || (($NW_FORMDATA['news_link']
                  && (
                    !$NW_FORMDATA['news_url']
                    || $NW_FORMDATA['news_url'] == 'http://')))
                || ($NW_FORMDATA['make_newdate'] == 'true'
                  && (
                    !$NW_FORMDATA['newdate_day']
                    || !$NW_FORMDATA['newdate_month']
                    || !$NW_FORMDATA['newdate_year']
                    || !preg_match('#\d{2}#',$NW_FORMDATA['newdate_day'])
                    || !preg_match('#\d{2}#',$NW_FORMDATA['newdate_month'])
                    || !preg_match('#\d{4}#',$NW_FORMDATA['newdate_year'])))
             )) {
        $error_msg = '<p>'.$NW_TRANSLATION['edit_error'].'</p><ul type="square">';
        if ($NW_FORMDATA['news_link'] && (!$NW_FORMDATA['news_url'] || $NW_FORMDATA['news_url'] == 'http://'))
          $error_msg .= '<li>'.$NW_TRANSLATION['edit_error_linkurl'].'</li>';
        if ($NW_FORMDATA['news_startdate'] && (!$NW_FORMDATA['startdate_day'] || !$NW_FORMDATA['startdate_month'] || !$NW_FORMDATA['startdate_year']))
          $error_msg .= '<li>'.$NW_TRANSLATION['edit_error_startdate'].'</li>';
        if ($NW_FORMDATA['news_expire'] && (!$NW_FORMDATA['expiredate_day'] || !$NW_FORMDATA['expiredate_month'] || !$NW_FORMDATA['expiredate_year']))
          $error_msg .= '<li>'.$NW_TRANSLATION['edit_error_expiredate'].'</li>';
        if ($NW_FORMDATA['make_newdate'] == 'true') {
          if (!$NW_FORMDATA['newdate_day'] || !$NW_FORMDATA['newdate_month'] || !$NW_FORMDATA['newdate_year'])
            $error_msg .= '<li>'.$NW_TRANSLATION['edit_error_date'].'</li>';
          if (!preg_match('#\d{2}#',$NW_FORMDATA['newdate_day']) || !preg_match('#\d{2}#',$NW_FORMDATA['newdate_month']) || !preg_match('#\d{4}#',$NW_FORMDATA['newdate_year']))
            $error_msg .= '<li>'.$NW_TRANSLATION['edit_error_datefmt'].'</li>';
        }
        $error_msg .= '</ul>';
        $NW_FORMDATA['nweditstep'] = 4;
      }
      echo $error_msg;
      $step = $NW_FORMDATA['nweditstep'] + 1;

      /* prepare texts for output inside the <input>-tags, hide quotes: */
      $NW_FORMDATA['news_title'] = prepare_text($NW_FORMDATA['news_title']);
      $NW_FORMDATA['news_text'] = prepare_text($NW_FORMDATA['news_text']);
      $NW_FORMDATA['news_atext'] = prepare_text($NW_FORMDATA['news_atext']);
      $NW_FORMDATA['news_subtopic'] = prepare_text($NW_FORMDATA['news_subtopic']);
      $NW_FORMDATA['img2_text'] = prepare_text($NW_FORMDATA['img2_text']);
      $NW_FORMDATA['news_lname'] = prepare_text($NW_FORMDATA['news_lname']);
      $NW_FORMDATA['news_title'] = strip_quots($NW_FORMDATA['news_title']);
      $NW_FORMDATA['news_text'] = strip_quots($NW_FORMDATA['news_text']);
      $NW_FORMDATA['news_atext'] = strip_quots($NW_FORMDATA['news_atext']);
      $NW_FORMDATA['news_subtopic'] = strip_quots($NW_FORMDATA['news_subtopic']);
      $NW_FORMDATA['img2_text'] = strip_quots($NW_FORMDATA['img2_text']);
      $NW_FORMDATA['news_lname'] = strip_quots($NW_FORMDATA['news_lname']);
      if ($NWCONF_INTERFACE['auto_br']) {
        $NW_FORMDATA['news_text'] = str_replace("<br />","\n",$NW_FORMDATA['news_text']);
        $NW_FORMDATA['news_atext'] = str_replace("<br />","\n",$NW_FORMDATA['news_atext']);
      }
      else {
        $NW_FORMDATA['news_text'] = str_replace("<br />","&lt;br&gt;",$NW_FORMDATA['news_text']);
        $NW_FORMDATA['news_atext'] = str_replace("<br />","&lt;br&gt;",$NW_FORMDATA['news_atext']);
      }

      if ($NW_FORMDATA['nweditstep'] < 5) {
        echo '<form action="'.$NWCONF_SYSTEM['domain_path'].'admin'.$NWCONF_SYSTEM['php_ext'].'" method="post" name="nwform_new">';
        echo '<input type="hidden" name="nwaction" value="'.$NW_RUNTIME['nwaction'].'">';
        echo '<input type="hidden" name="nwmode" value="edit">';
        echo '<input type="hidden" name="nweditstep" value="'.$step.'">';
        echo '<input type="hidden" name="nwpassword" value="'.$NW_RUNTIME['nwpassword'].'">';
        echo '<input type="hidden" name="nwlogin" value="'.$NW_RUNTIME['nwlogin'].'">';
        echo '<input type="hidden" name="file_name" value="'.$NW_FORMDATA['file_name'].'">';
        if ($NW_FORMDATA['nweditstep'] != 1 || !$NW_RUNTIME['admin_mode']) {
          echo '<input type="hidden" name="news_name" value="'.$NW_FORMDATA['news_name'].'">';
          echo '<input type="hidden" name="news_email" value="'.$NW_FORMDATA['news_email'].'">';
          echo '<input type="hidden" name="news_nwurl" value="'.$NW_FORMDATA['news_nwurl'].'">';
        }
        if ($NW_FORMDATA['nweditstep'] != 1) {
          echo '<input type="hidden" name="allow_html" value="'.$NW_FORMDATA['allow_html'].'">';
          echo '<input type="hidden" name="allow_bbcode" value="'.$NW_FORMDATA['allow_bbcode'].'">';
        }
        echo '<input type="hidden" name="news_date" value="'.$NW_FORMDATA['news_date'].'">';
      }

      if($NW_FORMDATA['nweditstep'] == 1) {
      /* Print the first edit page: */
        $NW_FORMDATA['news_title'] = add_quots($NW_FORMDATA['news_title']);
        $NW_FORMDATA['news_text'] = add_quots($NW_FORMDATA['news_text']);
        $NW_FORMDATA['news_subtopic'] = add_quots($NW_FORMDATA['news_subtopic']);

        echo '<input type="hidden" name="news_link" value="'.$NW_FORMDATA['news_link'].'">';
        echo '<input type="hidden" name="news_lname" value="'.$NW_FORMDATA['news_lname'].'">';
        echo '<input type="hidden" name="news_url" value="'.$NW_FORMDATA['news_url'].'">';
        echo '<input type="hidden" name="news_lopenwin" value="'.$NW_FORMDATA['news_lopenwin'].'">';
        echo '<input type="hidden" name="news_article" value="'.$NW_FORMDATA['news_article'].'">';
        echo '<input type="hidden" name="afile_name" value="'.$NW_FORMDATA['afile_name'].'">';
        echo '<input type="hidden" name="news_startdate" value="'.$NW_FORMDATA['news_startdate'].'">';
        echo '<input type="hidden" name="startdate_day" value="'.$NW_FORMDATA['startdate_day'].'">';
        echo '<input type="hidden" name="startdate_month" value="'.$NW_FORMDATA['startdate_month'].'">';
        echo '<input type="hidden" name="startdate_year" value="'.$NW_FORMDATA['startdate_year'].'">';
        echo '<input type="hidden" name="news_expire" value="'.$NW_FORMDATA['news_expire'].'">';
        echo '<input type="hidden" name="expiredate_day" value="'.$NW_FORMDATA['expiredate_day'].'">';
        echo '<input type="hidden" name="expiredate_month" value="'.$NW_FORMDATA['expiredate_month'].'">';
        echo '<input type="hidden" name="expiredate_year" value="'.$NW_FORMDATA['expiredate_year'].'">';
        if ($NW_FORMDATA['news_img1']) {
          echo '<input type="hidden" name="news_img1" value="true">';
          echo '<input type="hidden" name="img1_url" value="'.$NW_FORMDATA['img1_url'].'">';
          echo '<input type="hidden" name="img1_align" value="'.$NW_FORMDATA['img1_align'].'">';
        }
        if ($NW_FORMDATA['news_img2']) {
          echo '<input type="hidden" name="news_img2" value="true">';
          echo '<input type="hidden" name="img2_url" value="'.$NW_FORMDATA['img2_url'].'">';
          echo '<input type="hidden" name="img2_align" value="'.$NW_FORMDATA['img2_align'].'">';
          echo '<input type="hidden" name="img2_text" value="'.$NW_FORMDATA['img2_text'].'">';
        }
        if (!$NWCONF_INTERFACE['enable_subtopics'])
          echo '<input type="hidden" name="news_subtopic" value="'.$NW_FORMDATA['news_subtopic'].'">';
        echo '<table border="0" cellpadding="2" cellspacing="0" align="center" width="100%"><tr>';

        if ($NW_RUNTIME['admin_mode']) {
          echo '<td><b>'.$NW_TRANSLATION['edit_name'].'</b></td><td><input type="text" size="26" name="news_name" value="'.$NW_FORMDATA['news_name'].'">';
          if (check_for_admin(get_loginname($NW_FORMDATA['news_name'])))
            echo ' '.$NW_TRANSLATION['edit_admin'];
          echo '</td></tr><tr><td><b>'.$NW_TRANSLATION['edit_email'].'</b></td><td><input type="text" size="26" name="news_email" value="'.$NW_FORMDATA['news_email'].'">';
          echo '</td></tr><tr><td><b>'.$NW_TRANSLATION['edit_home'].'</b></td><td><input type="text" size="26" name="news_nwurl" value="'.$NW_FORMDATA['news_nwurl'].'">';
        }
        else {
          echo '<td><b>'.$NW_TRANSLATION['edit_name'].'</b></td><td>'.$NW_FORMDATA['news_name'].'</td>';
          echo '</tr><tr><td><b>'.$NW_TRANSLATION['edit_email'].'</b></td><td>';
          if ($NW_FORMDATA['news_email'])
            echo $NW_FORMDATA['news_email'];
          else
            echo '-';
          echo '</td></tr><tr><td><b>'.$NW_TRANSLATION['edit_home'].'</b></td><td>';
          if ($NW_FORMDATA['news_nwurl'])
            echo $NW_FORMDATA['news_nwurl'];
          else
            echo '-';
        }

        echo '</td></tr><tr><td colspan="2"><br /><b>';
        if ($NW_RUNTIME['nwmode'] == 'edit' && $NW_RUNTIME['nwaction'] == 'new')
          echo $NW_TRANSLATION['edit_createnew'];
        else
          echo $NW_TRANSLATION['edit_editnews'];
        echo '</b></td></tr>';

        echo '<tr><td>&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_topic'].'</td><td><select name="news_topic" size="1">';
        while (list($key,$topic) = each($NWCONF_INTERFACE['topic_list'])) {
          echo '<option value="'.$topic.'"';
          if ($topic == $NW_FORMDATA['news_topic'])
            echo ' selected';
          echo '>';
          if ($topic == 'all')
            echo $NW_TRANSLATION['topic_all'];
          else
            echo $topic;
          echo '</option>';
        }
        echo '</select></td></tr>';
        if ($NWCONF_INTERFACE['enable_subtopics'])
          echo '<tr><td>&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_subtopic'].'</td><td><input type="text" size="35" name="news_subtopic" value="'.$NW_FORMDATA['news_subtopic'].'"></td></tr>';

        echo '<tr><td>&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_title'].'</td><td><input type="text" size="35" name="news_title"';
        if ($NWCONF_INTERFACE['max_title_length'] > 0)
          echo ' maxlength="'.$NWCONF_INTERFACE['max_title_length'].'"';
        echo ' value="'.$NW_FORMDATA['news_title'].'"></td></tr>';
        echo '<tr><td valign="top">&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_text'].'</td><td><textarea cols="35" rows="8" name="news_text" wrap="virtual"';
        if ($NWCONF_INTERFACE['max_text_length'] > 0)
          echo ' onKeydown="CountMax();" onKeyup="CountMax();" onClick="CountMax();"';
        echo '>'.$NW_FORMDATA['news_text'].'</textarea>';
        if ($NWCONF_INTERFACE['max_text_length'] > 0) {
          $field_length = strlen($NWCONF_INTERFACE['max_text_length']) + 1;
          $max_length = $NWCONF_INTERFACE['max_text_length'] - strlen($NW_FORMDATA['news_text']);
          echo '<br />'.$NW_TRANSLATION['edit_maxtextlength1'].'<input type="text" name="rv_counter2" value="'.$max_length.'" size="'.$field_length.'" readonly onFocus="javascript:this.form.rv_counter2.blur();" style="border:0px;">'.$NW_TRANSLATION['edit_maxtextlength2'].'<br /><br />';
        }
        if ($NWCONF_INTERFACE['allow_html'] && is_array($NWCONF_INTERFACE['easy_tags'])) {
          echo '</td></tr><tr><td>&nbsp;&nbsp;&nbsp;<span style="font-size:9pt">'.$NW_TRANSLATION['edit_tags'].'</span></td><td><p>';
          while (list($key,$name) = each($NWCONF_INTERFACE['easy_tags'])) {
            echo '<a href="javascript:tag(\''.$name.'\')" class="easytags">'.$key.'</a>&nbsp;';
          }
          reset($NWCONF_INTERFACE['easy_tags']);
          echo '</p>';
        }
        if ($NWCONF_INTERFACE['allow_html']) {
          echo '</td></tr><tr><td>&nbsp;</td><td><br /><input type="checkbox" name="allow_html" value="true"';
          if (!$NW_FORMDATA['allow_html'] || $NW_FORMDATA['allow_html'] == 'true')
            echo 'checked';
          echo '> '.$NW_TRANSLATION['edit_usehtml'];
        }
        if ($NWCONF_INTERFACE['allow_bbcode']) {
          echo '</td></tr><tr><td>&nbsp;</td><td><input type="checkbox" name="allow_bbcode" value="true"';
          if (!$NW_FORMDATA['allow_bbcode'] || $NW_FORMDATA['allow_bbcode'] == 'true')
            echo 'checked';
          echo '> '.$NW_TRANSLATION['edit_usebbcode'];
        }
        echo '</td></tr><tr><td colspan="2"><br /><input type="submit" size="10" value="'.$NW_TRANSLATION['edit_forward'].'" style="width:80px"></td></tr></table>';

        if ($NW_RUNTIME['nwaction'] == 'edit' && !$error_msg) {
          echo '</form><form action="'.$NWCONF_SYSTEM['domain_path'].'admin'.$NWCONF_SYSTEM['php_ext'].'" method="post">';
          echo '<input type="hidden" name="nwmode" value="edit">';
          echo '<input type="hidden" name="nwaction" value = "delnews">';
          echo '<input type="hidden" name="file_name" value="'.$NW_FORMDATA['file_name'].'">';
          echo '<input type="hidden" name="nwpassword" value="'.$NW_RUNTIME['nwpassword'].'">';
          echo '<input type="hidden" name="nwlogin" value="'.$NW_RUNTIME['nwlogin'].'">';
          echo '<table border="0" cellpadding="2" cellspacing="0" align="center" width="100%">';
          echo '<tr><td><br /><p><input type="checkbox" name="delconfirm" value="true">'.$NW_TRANSLATION['edit_delete'].'<br />';
          echo $NW_TRANSLATION['edit_deletewarning'].'</p></td></tr>';
          echo '<tr><td><input type="submit" size="35" value="'.$NW_TRANSLATION['edit_deleteconfirm'].'" style="width:200px"></td></tr>';
          echo '</table>';
          echo '</form>';
        }
      }

      elseif ($NW_FORMDATA['nweditstep'] == 2) {
       /* Print the second edit page: */
        if ($NW_FORMDATA['afile_name']) {
          $NW_FORMDATA['news_atext'] = get_article($NW_FORMDATA['afile_name']);
        }
        else {
          $NW_FORMDATA['news_atext'] = add_quots($NW_FORMDATA['news_atext']);
        }
        if ($NW_FORMDATA['news_atext']) {
          if ($NWCONF_INTERFACE['allow_bbcode'])
            $NW_FORMDATA['news_atext'] = html2bbcode($NW_FORMDATA['news_atext']);
          if ($NWCONF_INTERFACE['make_links'])
            $NW_FORMDATA['news_atext'] = preg_replace('#<a href=[^>]*>(\w+)://(.+?)</a>#i','\\1://\\2',$NW_FORMDATA['news_atext']);
          $NW_FORMDATA['news_atext'] = prepare_text($NW_FORMDATA['news_atext']);
          if ($NWCONF_INTERFACE['auto_br'])
            $NW_FORMDATA['news_atext'] = str_replace("<br />","\n",$NW_FORMDATA['news_atext']);
          else
            $NW_FORMDATA['news_atext'] = str_replace("<br />","&lt;br&gt;",$NW_FORMDATA['news_atext']);
        }

        echo '<input type="hidden" name="news_topic" value="'.$NW_FORMDATA['news_topic'].'">';
        echo '<input type="hidden" name="news_subtopic" value="'.$NW_FORMDATA['news_subtopic'].'">';
        echo '<input type="hidden" name="news_title" value="'.$NW_FORMDATA['news_title'].'">';
        echo '<input type="hidden" name="news_text" value="'.$NW_FORMDATA['news_text'].'">';
        echo '<input type="hidden" name="news_link" value="'.$NW_FORMDATA['news_link'].'">';
        echo '<input type="hidden" name="news_url" value="'.$NW_FORMDATA['news_url'].'">';
        echo '<input type="hidden" name="news_lname" value="'.$NW_FORMDATA['news_lname'].'">';
        echo '<input type="hidden" name="news_lopenwin" value="'.$NW_FORMDATA['news_lopenwin'].'">';
        echo '<input type="hidden" name="afile_name" value="'.$NW_FORMDATA['afile_name'].'">';
        echo '<input type="hidden" name="news_startdate" value="'.$NW_FORMDATA['news_startdate'].'">';
        echo '<input type="hidden" name="startdate_day" value="'.$NW_FORMDATA['startdate_day'].'">';
        echo '<input type="hidden" name="startdate_month" value="'.$NW_FORMDATA['startdate_month'].'">';
        echo '<input type="hidden" name="startdate_year" value="'.$NW_FORMDATA['startdate_year'].'">';
        echo '<input type="hidden" name="news_expire" value="'.$NW_FORMDATA['news_expire'].'">';
        echo '<input type="hidden" name="expiredate_day" value="'.$NW_FORMDATA['expiredate_day'].'">';
        echo '<input type="hidden" name="expiredate_month" value="'.$NW_FORMDATA['expiredate_month'].'">';
        echo '<input type="hidden" name="expiredate_year" value="'.$NW_FORMDATA['expiredate_year'].'">';
        if ($NW_FORMDATA['news_img1']) {
          echo '<input type="hidden" name="news_img1" value="true">';
          echo '<input type="hidden" name="img1_url" value="'.$NW_FORMDATA['img1_url'].'">';
          echo '<input type="hidden" name="img1_align" value="'.$NW_FORMDATA['img1_align'].'">';
        }
        if ($NW_FORMDATA['news_img2']) {
          echo '<input type="hidden" name="news_img2" value="true">';
          echo '<input type="hidden" name="img2_url" value="'.$NW_FORMDATA['img2_url'].'">';
          echo '<input type="hidden" name="img2_align" value="'.$NW_FORMDATA['img2_align'].'">';
          echo '<input type="hidden" name="img2_text" value="'.$NW_FORMDATA['img2_text'].'">';
        }

        echo '<table border="0" cellpadding="2" cellspacing="0" align="center" width="100%">';

        echo '<tr><td colspan="2"><br /><input type="checkbox" name="news_article" value="true"';
        if ($NW_FORMDATA['news_article'] || $NW_FORMDATA['afile_name'])
          echo 'checked';
        echo '>'.$NW_TRANSLATION['edit_usearticlepage'].'</td></tr><tr><td colspan="2">';

        echo '<br /><textarea cols="45" rows="16" name="news_atext" style="width:100%" wrap="virtual" onChange="javascript:if (!document.nwform_new.news_article.checked) { document.nwform_new.news_article.click(); }">'.$NW_FORMDATA['news_atext'].'</textarea>';
        if ($NWCONF_INTERFACE['allow_html'] && is_array($NWCONF_INTERFACE['easy_tags'])) {
          echo '<br /><span style="font-size:9pt">'.$NW_TRANSLATION['edit_tags'].'&nbsp;&nbsp;';
          while (list($key,$name) = each($NWCONF_INTERFACE['easy_tags'])) {
            echo '<a href="javascript:tag(\''.$name.'\')" style="color:#000000">'.$key.'</a>&nbsp;';
          }
          reset($NWCONF_INTERFACE['easy_tags']);
          echo '</span>';
        }
        echo '</td></tr><tr><td colspan="2"><br /><input type="button" size="10" onClick="javascript:history.back()" value="'.$NW_TRANSLATION['edit_back'].'" style="width:80px">&nbsp;&nbsp;<input type="submit" size="10" value="'.$NW_TRANSLATION['edit_forward'].'" style="width:80px"></td></tr></table>';
      }

      elseif ($NW_FORMDATA['nweditstep'] == 3) {
       /* Print the third edit page: */
        $picarchiv = get_complete_dirlist($NWCONF_SYSTEM['server_path'].$NWCONF_SYSTEM['imgupload_dir'], true);
        echo '<input type="hidden" name="news_topic" value="'.$NW_FORMDATA['news_topic'].'">';
        echo '<input type="hidden" name="news_subtopic" value="'.$NW_FORMDATA['news_subtopic'].'">';
        echo '<input type="hidden" name="news_title" value="'.$NW_FORMDATA['news_title'].'">';
        echo '<input type="hidden" name="news_text" value="'.$NW_FORMDATA['news_text'].'">';
        echo '<input type="hidden" name="news_link" value="'.$NW_FORMDATA['news_link'].'">';
        echo '<input type="hidden" name="news_url" value="'.$NW_FORMDATA['news_url'].'">';
        echo '<input type="hidden" name="news_lname" value="'.$NW_FORMDATA['news_lname'].'">';
        echo '<input type="hidden" name="news_lopenwin" value="'.$NW_FORMDATA['news_lopenwin'].'">';
        echo '<input type="hidden" name="news_article" value="'.$NW_FORMDATA['news_article'].'">';
        echo '<input type="hidden" name="afile_name" value="'.$NW_FORMDATA['afile_name'].'">';
        echo '<input type="hidden" name="news_atext" value="'.$NW_FORMDATA['news_atext'].'">';
        echo '<input type="hidden" name="news_startdate" value="'.$NW_FORMDATA['news_startdate'].'">';
        echo '<input type="hidden" name="startdate_day" value="'.$NW_FORMDATA['startdate_day'].'">';
        echo '<input type="hidden" name="startdate_month" value="'.$NW_FORMDATA['startdate_month'].'">';
        echo '<input type="hidden" name="startdate_year" value="'.$NW_FORMDATA['startdate_year'].'">';
        echo '<input type="hidden" name="news_expire" value="'.$NW_FORMDATA['news_expire'].'">';
        echo '<input type="hidden" name="expiredate_day" value="'.$NW_FORMDATA['expiredate_day'].'">';
        echo '<input type="hidden" name="expiredate_month" value="'.$NW_FORMDATA['expiredate_month'].'">';
        echo '<input type="hidden" name="expiredate_year" value="'.$NW_FORMDATA['expiredate_year'].'">';

        echo '<table border="0" cellpadding="2" cellspacing="0" align="center" width="100%">';
        echo '<tr><td colspan="2"><br /><input type="checkbox" name="news_img1" value="true"';
        if ($NW_FORMDATA['news_img1'] || $userimg_name[0])
          echo ' checked';
        echo '>'.$NW_TRANSLATION['edit_picture_newspage'].'</td></tr>';
        echo '<tr><td>&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_picturelist'].'</td><td><select name="imgarchiv1" size="1" onChange="javascript:selectImg(\'img1_url\',\'imgarchiv1\',\''.$NW_FORMDATA['img1_url'].'\',\'news_img1\');">';
        echo '<option value="">'.$NW_TRANSLATION['edit_imguserurl'].'</option>';
        if ($picarchiv) {
          while (list($key,$pic) = each($picarchiv)) {
            $pic = basename($pic);
            echo '<option value="'.$pic.'">'.$pic.'</option>';
          }
          reset($picarchiv);
        }
        echo '</select> <input type="button" value="'.$NW_TRANSLATION['edit_imagepreview'].'" onClick="javascipt:previewImg(\'img1_url\',false);"></td></tr>';
        echo '<tr><td>&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_pictureurl'].'</td><td><input type="text" size="35" name="img1_url" value="';
        if ($userimg_name[0])
          echo $NWCONF_SYSTEM['domain_path'].$NWCONF_SYSTEM['imgupload_dir'].'/'.$userimg_name[0];
        else
          echo $NW_FORMDATA['img1_url'];
        echo '" onChange="javascript:editImg(\'img1_url\',\'imgarchiv1\',\'news_img1\');"></td></tr>';
        echo '<tr><td>&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_alignment'].'</td><td><input type="radio" name="img1_align" value="left"';
        if ($NW_FORMDATA['img1_align'] != 'right' && $NW_FORMDATA['img1_align'] != 'ontop')
          echo ' checked';
        echo '>'.$NW_TRANSLATION['edit_left'].'&nbsp;&nbsp;&nbsp;<input type="radio" name="img1_align" value="right"';
        if ($NW_FORMDATA['img1_align'] == 'right')
          echo ' checked';
        echo '>'.$NW_TRANSLATION['edit_right'].'&nbsp;&nbsp;&nbsp;<input type="radio" name="img1_align" value="ontop"';
        if ($NW_FORMDATA['img1_align'] == 'ontop')
          echo ' checked';
        echo '>'.$NW_TRANSLATION['edit_abovetext'].'</td></tr>';

        if ($NW_FORMDATA['news_article']) {
          $NW_FORMDATA['img2_text'] = add_quots($NW_FORMDATA['img2_text']);
          echo '<tr><td colspan="2"><br /><br /><input type="checkbox" name="news_img2" value="true"';
          if ($NW_FORMDATA['news_img2'] || $userimg_name[1])
            echo ' checked';
          echo '>'.$NW_TRANSLATION['edit_picture_articlepage'].'</td></tr>';
          echo '<tr><td>&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_picturelist'].'</td><td><select name="imgarchiv2" size="1" onChange="javascript:selectImg(\'img2_url\',\'imgarchiv2\',\''.$NW_FORMDATA['img2_url'].'\',\'news_img2\');">';
          echo '<option value="">'.$NW_TRANSLATION['edit_imguserurl'].'</option>';
          if ($picarchiv) {
            while (list($key,$pic) = each($picarchiv)) {
              $pic = basename($pic);
              echo '<option value="'.$pic.'">'.$pic.'</option>';
            }
            reset($picarchiv);
          }
          echo '</select>  <input type="button" value="'.$NW_TRANSLATION['edit_imagepreview'].'" onClick="javascipt:previewImg(\'img2_url\',true);"></td></tr>';
          echo '<tr><td>&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_pictureurl'].'</td><td><input type="text" size="35" name="img2_url" value="';
          if ($userimg_name[1])
            echo $NWCONF_SYSTEM['domain_path'].$NWCONF_SYSTEM['imgupload_dir'].'/'.$userimg_name[1];
          else
            echo $NW_FORMDATA['img2_url'];
          echo '" onChange="javascript:editImg(\'img2_url\',\'imgarchiv2\',\'news_img2\');"></td></tr>';
          echo '<tr><td>&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_alignment'].'</td><td><input type="radio" name="img2_align" value="left"';
          if ($NW_FORMDATA['img2_align'] != 'right' && $NW_FORMDATA['img2_align'] != 'ontop')
            echo ' checked';
          echo '>'.$NW_TRANSLATION['edit_left'].'&nbsp;&nbsp;&nbsp;<input type="radio" name="img2_align" value="right"';
          if ($NW_FORMDATA['img2_align'] == 'right')
            echo ' checked';
          echo '>'.$NW_TRANSLATION['edit_right'].'&nbsp;&nbsp;&nbsp;<input type="radio" name="img2_align" value="ontop"';
          if ($NW_FORMDATA['img2_align'] == 'ontop')
            echo ' checked';
          echo '>'.$NW_TRANSLATION['edit_abovetext'].'</td></tr>';
          echo '<tr><td>&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_imagetext'].'</td><td><input type="text" size="35" name="img2_text" value="'.$NW_FORMDATA['img2_text'].'"></td></tr>';
        }
        echo '<tr><td colspan="2"><br /><input type="button" size="10" onClick="javascript:history.back()" value="'.$NW_TRANSLATION['edit_back'].'" style="width:80px">&nbsp;&nbsp;<input type="submit" size="10" value="'.$NW_TRANSLATION['edit_forward'].'" style="width:80px"></td></tr></table>';
        if ($NWCONF_INTERFACE['allow_imgupload']) {
          $maxbytes = $NWCONF_INTERFACE['img_maxsize'] * 1024;
          echo '</form><form enctype="multipart/form-data" action="'.$NWCONF_SYSTEM['domain_path'].'admin'.$NWCONF_SYSTEM['php_ext'].'" method="post">';
          echo '<input type="hidden" name="nwaction" value="upload">';
          echo '<input type="hidden" name="nwmode" value="edit">';
          echo '<input type="hidden" name="nweditstep" value="'.$NW_FORMDATA['nweditstep'].'">';
          echo '<input type="hidden" name="nwpassword" value="'.$NW_RUNTIME['nwpassword'].'">';
          echo '<input type="hidden" name="nwlogin" value="'.$NW_RUNTIME['nwlogin'].'">';
          echo '<input type="hidden" name="file_name" value="'.$NW_FORMDATA['file_name'].'">';
          echo '<input type="hidden" name="news_name" value="'.$NW_FORMDATA['news_name'].'">';
          echo '<input type="hidden" name="news_email" value="'.$NW_FORMDATA['news_email'].'">';
          echo '<input type="hidden" name="news_nwurl" value="'.$NW_FORMDATA['news_nwurl'].'">';
          echo '<input type="hidden" name="news_date" value="'.$NW_FORMDATA['news_date'].'">';
          echo '<input type="hidden" name="news_topic" value="'.$NW_FORMDATA['news_topic'].'">';
          echo '<input type="hidden" name="news_subtopic" value="'.$NW_FORMDATA['news_subtopic'].'">';
          echo '<input type="hidden" name="news_title" value="'.$NW_FORMDATA['news_title'].'">';
          echo '<input type="hidden" name="news_text" value="'.$NW_FORMDATA['news_text'].'">';
          echo '<input type="hidden" name="news_article" value="'.$NW_FORMDATA['news_article'].'">';
          echo '<input type="hidden" name="afile_name" value="'.$NW_FORMDATA['afile_name'].'">';
          echo '<input type="hidden" name="news_atext" value="'.$NW_FORMDATA['news_atext'].'">';
          if ($NW_FORMDATA['news_img1']) {
            echo '<input type="hidden" name="news_img1" value="true">';
            echo '<input type="hidden" name="img1_url" value="'.$NW_FORMDATA['img1_url'].'">';
            echo '<input type="hidden" name="img1_align" value="'.$NW_FORMDATA['img1_align'].'">';
          }
          if ($NW_FORMDATA['news_img2']) {
            echo '<input type="hidden" name="news_img2" value="true">';
            echo '<input type="hidden" name="img2_url" value="'.$NW_FORMDATA['img2_url'].'">';
            echo '<input type="hidden" name="img2_align" value="'.$NW_FORMDATA['img2_align'].'">';
            echo '<input type="hidden" name="img2_text" value="'.$NW_FORMDATA['img2_text'].'">';
          }
          echo '<input type="hidden" name="allow_html" value="'.$NW_FORMDATA['allow_html'].'">';
          echo '<input type="hidden" name="allow_bbcode" value="'.$NW_FORMDATA['allow_bbcode'].'">';

          echo '<br /><table border="0" cellpadding="2" cellspacing="0" align="center" width="100%"><tr><td>';
          echo $NW_TRANSLATION['edit_imageupload1'].$NWCONF_INTERFACE['img_maxsize'].$NW_TRANSLATION['edit_imageupload2'].'</td></tr><tr><td>';
          if ($NW_MESSAGES['upload_success'])
            echo '<p>'.$NW_MESSAGES['upload_success'].'</p></td></tr><tr><td>';
          if ($NW_MESSAGES['upload_error'])
            echo '<p>'.$NW_MESSAGES['upload_error'].'</p></td></tr><tr><td>';
          echo /*$NW_TRANSLATION['edit_uploadnewspage'].*/'<br /><input type="file" name="userimg[]" size="35" maxlength="255"></td></tr><tr><td>';
          //echo $NW_TRANSLATION['edit_uploadarticle'].'<br /><input type="file" name="userimg[]" size="35" maxlength="255"></td></tr><tr><td>';
          echo '<input type="submit" size="35" value="'.$NW_TRANSLATION['edit_startupload'].'" style="width:200px"></p>';
          echo '</td></tr></table>';
        }
      }
      elseif ($NW_FORMDATA['nweditstep'] == 4) {
       /* Print the fourth edit page: */
        $NW_FORMDATA['news_lname'] = add_quots($NW_FORMDATA['news_lname']);

        echo '<input type="hidden" name="news_topic" value="'.$NW_FORMDATA['news_topic'].'">';
        echo '<input type="hidden" name="news_subtopic" value="'.$NW_FORMDATA['news_subtopic'].'">';
        echo '<input type="hidden" name="news_title" value="'.$NW_FORMDATA['news_title'].'">';
        echo '<input type="hidden" name="news_text" value="'.$NW_FORMDATA['news_text'].'">';
        echo '<input type="hidden" name="news_article" value="'.$NW_FORMDATA['news_article'].'">';
        echo '<input type="hidden" name="afile_name" value="'.$NW_FORMDATA['afile_name'].'">';
        echo '<input type="hidden" name="news_atext" value="'.$NW_FORMDATA['news_atext'].'">';
        if ($NW_FORMDATA['news_img1']) {
          echo '<input type="hidden" name="news_img1" value="true">';
          echo '<input type="hidden" name="img1_url" value="'.$NW_FORMDATA['img1_url'].'">';
          echo '<input type="hidden" name="img1_align" value="'.$NW_FORMDATA['img1_align'].'">';
        }
        if ($NW_FORMDATA['news_img2']) {
          echo '<input type="hidden" name="news_img2" value="true">';
          echo '<input type="hidden" name="img2_url" value="'.$NW_FORMDATA['img2_url'].'">';
          echo '<input type="hidden" name="img2_align" value="'.$NW_FORMDATA['img2_align'].'">';
          echo '<input type="hidden" name="img2_text" value="'.$NW_FORMDATA['img2_text'].'">';
        }
        echo '<table border="0" cellpadding="2" cellspacing="0" align="center" width="100%">';
        echo '<tr><td colspan="2"><br /><input type="checkbox" name="news_link" value="true"';
        if ($NW_FORMDATA['news_link'])
          echo ' checked';
        echo '>'.$NW_TRANSLATION['edit_link'].'</td></tr>';
        echo '<tr><td width="100">&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_linkname'].'</td><td><input type="text" size="16" name="news_lname" value="'.$NW_FORMDATA['news_lname'].'">&nbsp;'.$NW_TRANSLATION['edit_linkdisplayhelp'].'</td></tr>';
        echo '<tr><td>&nbsp;&nbsp;&nbsp;'.$NW_TRANSLATION['edit_linkurl'].'</td><td><input type="text" size="35" name="news_url" value="'.$NW_FORMDATA['news_url'].'"></td></tr>';
        echo '<tr><td colspan="2">&nbsp;&nbsp;&nbsp;<input type="checkbox" name="news_lopenwin" value="true"';
        if ($NW_FORMDATA['news_lopenwin'])
          echo ' checked';
        echo '>'.$NW_TRANSLATION['edit_linknewwindow'].'<br /><br /></td></tr>';
        echo '</table><table border="0" cellpadding="2" cellspacing="0" align="center" width="100%">';
        echo '<tr><td width="180"><input type="checkbox" name="news_startdate" value="true"';
        if ($NW_FORMDATA['news_startdate'])
          echo ' checked>';
        echo $NW_TRANSLATION['edit_startdate'];
        echo '</td><td><input type="text" size="2" maxlength="2" name="startdate_day" value="'.$NW_FORMDATA['startdate_day'].'">.<input type="text" size="2" maxlength="2" name="startdate_month" value="'.$NW_FORMDATA['startdate_month'].'">.<input type="text" size="4" maxlength="4" name="startdate_year" value="'.$NW_FORMDATA['startdate_year'].'"></td></tr>';
        echo '<tr><td><input type="checkbox" name="news_expire" value="true"';
        if ($NW_FORMDATA['news_expire'])
          echo ' checked>';
        echo $NW_TRANSLATION['edit_expiredate'];
        echo '</td><td><input type="text" size="2" maxlength="2" name="expiredate_day" value="'.$NW_FORMDATA['expiredate_day'].'">.<input type="text" size="2" maxlength="2" name="expiredate_month" value="'.$NW_FORMDATA['expiredate_month'].'">.<input type="text" size="4" maxlength="4" name="expiredate_year" value="'.$NW_FORMDATA['expiredate_year'].'"></td></tr>';

        if ($NWCONF_INTERFACE['change_date'] && $NW_RUNTIME['admin_mode']) {
          if (!$NW_FORMDATA['newdate_day'])
            $NW_FORMDATA['newdate_day'] = strftime('%d',$NW_RUNTIME['act_timestamp']);
          if (!$NW_FORMDATA['newdate_month'])
            $NW_FORMDATA['newdate_month'] = strftime('%m',$NW_RUNTIME['act_timestamp']);
          if (!$NW_FORMDATA['newdate_year'])
            $NW_FORMDATA['newdate_year'] = strftime('%Y',$NW_RUNTIME['act_timestamp']);

          echo '<tr><td colspan="2"><br />'.$NW_TRANSLATION['edit_date'].'</td></tr>';
          echo '<tr><td colspan="2"><input type="radio" name="make_newdate" value="false"';
          if ($NW_FORMDATA['make_newdate'] != 'true')
            echo ' checked';
          echo '>'.$NW_TRANSLATION['edit_keepdate'];
          if ($NW_FORMDATA['file_name'])
            echo '&nbsp;('.strftime($NWCONF_DISPLAY['date_fmt'],basename($NW_FORMDATA['file_name'])).')';
          else
            echo '&nbsp;('.strftime($NWCONF_DISPLAY['date_fmt'],$NW_RUNTIME['act_timestamp']).')';
          echo '</td></tr><tr><td colspan="2"><input type="radio" name="make_newdate" value="true"';
          if ($NW_FORMDATA['make_newdate'] == 'true')
            echo ' checked';
          echo '>'.$NW_TRANSLATION['edit_newdate'].'</td></tr>';
          echo '<tr><td colspan="2">&nbsp;&nbsp;&nbsp;<input type="text" size="2" maxlength="2" name="newdate_day" value="'.$NW_FORMDATA['newdate_day'].'">
               .<input type="text" size="2" maxlength="2" name="newdate_month" value="'.$NW_FORMDATA['newdate_month'].'">
               .<input type="text" size="4" maxlength="4" name="newdate_year" value="'.$NW_FORMDATA['newdate_year'].'"></td></tr>';
        }

        echo '<tr><td colspan="2"><br /><input type="button" size="10" onClick="javascript:history.back()" value="'
             .$NW_TRANSLATION['edit_back'].'" style="width:80px">&nbsp;&nbsp;<input type="submit" size="10" value="'
             .$NW_TRANSLATION['edit_forward'].'" style="width:80px"></td></tr></table>';
      }
      else {
       /* Print preview page: */
        echo '<form action="'.$NWCONF_SYSTEM['domain_path'].'admin'.$NWCONF_SYSTEM['php_ext'].'" method="post" name="nwform_new">';
        echo '<input type="hidden" name="nwaction" value="adnews">';
        echo '<input type="hidden" name="nwmode" value="edit">';
        echo '<input type="hidden" name="nwpassword" value="'.$NW_RUNTIME['nwpassword'].'">';
        echo '<input type="hidden" name="nwlogin" value="'.$NW_RUNTIME['nwlogin'].'">';
        echo '<input type="hidden" name="file_name" value="'.$NW_FORMDATA['file_name'].'">';
        echo '<input type="hidden" name="news_name" value="'.$NW_FORMDATA['news_name'].'">';
        echo '<input type="hidden" name="news_email" value="'.$NW_FORMDATA['news_email'].'">';
        echo '<input type="hidden" name="news_nwurl" value="'.$NW_FORMDATA['news_nwurl'].'">';
        echo '<input type="hidden" name="news_date" value="'.$NW_FORMDATA['news_date'].'">';

        echo '<input type="hidden" name="news_topic" value="'.$NW_FORMDATA['news_topic'].'">';
        echo '<input type="hidden" name="news_subtopic" value="'.$NW_FORMDATA['news_subtopic'].'">';
        echo '<input type="hidden" name="news_title" value="'.$NW_FORMDATA['news_title'].'">';
        echo '<input type="hidden" name="news_text" value="'.$NW_FORMDATA['news_text'].'">';
        echo '<input type="hidden" name="news_article" value="'.$NW_FORMDATA['news_article'].'">';
        echo '<input type="hidden" name="afile_name" value="'.$NW_FORMDATA['afile_name'].'">';
        echo '<input type="hidden" name="news_atext" value="'.$NW_FORMDATA['news_atext'].'">';
        echo '<input type="hidden" name="news_link" value="'.$NW_FORMDATA['news_link'].'">';
        echo '<input type="hidden" name="news_url" value="'.$NW_FORMDATA['news_url'].'">';
        echo '<input type="hidden" name="news_lname" value="'.$NW_FORMDATA['news_lname'].'">';
        echo '<input type="hidden" name="news_lopenwin" value="'.$NW_FORMDATA['news_lopenwin'].'">';
        echo '<input type="hidden" name="news_startdate" value="'.$NW_FORMDATA['news_startdate'].'">';
        echo '<input type="hidden" name="startdate_day" value="'.$NW_FORMDATA['startdate_day'].'">';
        echo '<input type="hidden" name="startdate_month" value="'.$NW_FORMDATA['startdate_month'].'">';
        echo '<input type="hidden" name="startdate_year" value="'.$NW_FORMDATA['startdate_year'].'">';
        echo '<input type="hidden" name="news_expire" value="'.$NW_FORMDATA['news_expire'].'">';
        echo '<input type="hidden" name="expiredate_day" value="'.$NW_FORMDATA['expiredate_day'].'">';
        echo '<input type="hidden" name="expiredate_month" value="'.$NW_FORMDATA['expiredate_month'].'">';
        echo '<input type="hidden" name="expiredate_year" value="'.$NW_FORMDATA['expiredate_year'].'">';
        echo '<input type="hidden" name="make_newdate" value="'.$NW_FORMDATA['make_newdate'].'">';
        echo '<input type="hidden" name="newdate_day" value="'.$NW_FORMDATA['newdate_day'].'">';
        echo '<input type="hidden" name="newdate_month" value="'.$NW_FORMDATA['newdate_month'].'">';
        echo '<input type="hidden" name="newdate_year" value="'.$NW_FORMDATA['newdate_year'].'">';
        if ($NW_FORMDATA['news_img1']) {
          echo '<input type="hidden" name="news_img1" value="true">';
          echo '<input type="hidden" name="img1_url" value="'.$NW_FORMDATA['img1_url'].'">';
          echo '<input type="hidden" name="img1_align" value="'.$NW_FORMDATA['img1_align'].'">';
        }
        if ($NW_FORMDATA['news_img2']) {
          echo '<input type="hidden" name="news_img2" value="true">';
          echo '<input type="hidden" name="img2_url" value="'.$NW_FORMDATA['img2_url'].'">';
          echo '<input type="hidden" name="img2_align" value="'.$NW_FORMDATA['img2_align'].'">';
          echo '<input type="hidden" name="img2_text" value="'.$NW_FORMDATA['img2_text'].'">';
        }
        echo '<input type="hidden" name="allow_html" value="'.$NW_FORMDATA['allow_html'].'">';
        echo '<input type="hidden" name="allow_bbcode" value="'.$NW_FORMDATA['allow_bbcode'].'">';

        $NW_FORMDATA['news_title'] = add_quots($NW_FORMDATA['news_title']);
        $NW_FORMDATA['news_text'] = add_quots($NW_FORMDATA['news_text']);
        $NW_FORMDATA['news_subtopic'] = add_quots($NW_FORMDATA['news_subtopic']);
        $NW_FORMDATA['news_lname'] = add_quots($NW_FORMDATA['news_lname']);
        $NW_FORMDATA['img2_text'] = add_quots($NW_FORMDATA['img2_text']);
        $NW_FORMDATA['news_title'] = prepare_text($NW_FORMDATA['news_title']);
        $NW_FORMDATA['news_subtopic'] = prepare_text($NW_FORMDATA['news_subtopic']);
        $NW_FORMDATA['news_text'] = prepare_text($NW_FORMDATA['news_text']);
        $NW_FORMDATA['news_lname'] = prepare_text($NW_FORMDATA['news_lname']);
        $NW_FORMDATA['img2_text'] = prepare_text($NW_FORMDATA['img2_text']);
        $NW_FORMDATA['news_atext'] = add_quots($NW_FORMDATA['news_atext']);
        $NW_FORMDATA['news_atext'] = prepare_text($NW_FORMDATA['news_atext']);
        if ($NWCONF_INTERFACE['allow_bbcode'] && $NW_FORMDATA['allow_bbcode']) {
          $NW_FORMDATA['news_text'] = bbcode2html($NW_FORMDATA['news_text']);
          $NW_FORMDATA['news_atext'] = bbcode2html($NW_FORMDATA['news_atext']);
        }
        if ($NWCONF_INTERFACE['make_links']) {
          $NW_FORMDATA['news_text'] = link_url($NW_FORMDATA['news_text']);
          $NW_FORMDATA['news_atext'] = link_url($NW_FORMDATA['news_atext']);
        }

        echo '<p><b>'.$NW_FORMDATA['news_title'].'</b><br /><font color="#808080">'.$NW_FORMDATA['news_subtopic'].'</font></p><p>';
        if ($NW_FORMDATA['news_img1']) {
          $img_tag = '<img src="'.$NW_FORMDATA['img1_url'].'" border="0" alt="'.$file_entries['TITLE'].'" vspace="'.$NWCONF_DISPLAY['image_space'].'" hspace="'.$NWCONF_DISPLAY['image_space'].'"';
          if ($NW_FORMDATA['img1_align'] == 'ontop')
            $img_tag .= '><br clear="all">';
          else
            $img_tag .= ' align="'.$NW_FORMDATA['img1_align'].'">';
          echo $img_tag;
        }
        echo '<i>'.$NW_FORMDATA['news_text'].'</i>';
        if ($NW_FORMDATA['news_article']) {
          echo '</p><br clear="all"><p>';
          if ($NW_FORMDATA['news_img2']) {
            $img_tag = '<img src="'.$NW_FORMDATA['img2_url'].'" border="0" alt="'.$file_entries['TITLE'].'" vspace="'.$NWCONF_DISPLAY['image_space'].'" hspace="'.$NWCONF_DISPLAY['image_space'].'"';
            if ($NW_FORMDATA['img2_align'] == 'ontop')
              $img_tag .= '><br clear="all">';
            else
              $img_tag .= ' align="'.$NW_FORMDATA['img2_align'].'">';
            echo $img_tag;
          }
          echo $NW_FORMDATA['news_atext'];
        }
        if ($NW_FORMDATA['news_link'])
          echo '&nbsp;<a href="'.$NW_FORMDATA['news_url'].'" target="_blank">'.$NW_FORMDATA['news_lname'].'</a>';
        echo '</p><p>'.$NW_FORMDATA['news_name'].'</p><br clear="all">';
				echo '<p><input type="checkbox" name="send_newsletter" value="true"> Diesen Beitrag als Newsletter versenden</p>';
        echo '<p><input type="button" size="10" onClick="javascript:history.back()" value="'.$NW_TRANSLATION['edit_back'].'" style="width:80px">&nbsp;&nbsp;<input type="submit" size="35" value="'.$NW_TRANSLATION['edit_publish'].'" style="width:200px"></p>';
      }
      echo '</form>';
    }
    else {
      echo '<p>'.$NW_TRANSLATION['edit_nottheauhtor'].'</p>';
      echo '<ul>';
      echo '<a href="'.$NWCONF_SYSTEM['domain_path'].'admin'.$NWCONF_SYSTEM['php_ext'].'?nwaction=shownews&nwmode=edit&nwlogin='.$NW_RUNTIME['nwlogin'].'&nwpassword='.$NW_RUNTIME['nwpassword'].'">'.$NW_TRANSLATION['edit_nottheauhtor_edit'].'</a><br />';
      echo '<a href="'.$NWCONF_SYSTEM['domain_path'].'admin'.$NWCONF_SYSTEM['php_ext'].'?nwaction=new&nwmode=edit&nwlogin='.$NW_RUNTIME['nwlogin'].'&nwpassword='.$NW_RUNTIME['nwpassword'].'">'.$NW_TRANSLATION['edit_nottheauhtor_new'].'</a>';
      echo '</ul>';
    }
  }
  elseif ($NW_RUNTIME['nwaction'] == 'adnews') {
    ad_news();
		if ($NWCONF_NEWSLETTER['send_newsletter'] == true && $HTTP_POST_VARS['send_newsletter'] == 'true')
    {
      send_newsletter();
    }
		send_infomail();
    show_news();
  }

  elseif ($NW_RUNTIME['nwaction'] == 'delnews') {
    del_news($NW_FORMDATA['file_name']);
    show_news();
  }

  elseif ($NW_RUNTIME['nwaction'] == 'shownews') {
    show_news();
  }
}

//Newsletter versenden (05.08.2002 Raphael Zimmer <raphaelzimmer@web.de>)
function send_newsletter()
{
  global $NW_FORMDATA, $NW_RUNTIME, $NW_TRANSLATION, $NWCONF_SYSTEM, $NWCONF_USERS, $NWCONF_NEWSLETTER;
  global $HTTP_SERVER_VARS;
  $mail_tpl = file($NWCONF_SYSTEM['server_path'].$NWCONF_SYSTEM['template_dir'].'admin/newsletter.tpl');
  $archiv_url = $NWCONF_SYSTEM['index_file'].'?nwaction=shownews&nwmode=archiv&newsmonth='.strftime('%Y%m', $NW_RUNTIME['act_timestamp']).'#'.$NW_RUNTIME['act_timestamp'];
  if ($HTTP_SERVER_VARS['SERVER_URL'])
    $link = rmv_slash($HTTP_SERVER_VARS['SERVER_URL']).str_replace($HTTP_SERVER_VARS['SERVER_URL'],'/',$NWCONF_SYSTEM['domain_path']).$archiv_url;
  elseif ($HTTP_SERVER_VARS['SERVER_NAME'])
    $link = 'http://'.rmv_slash($HTTP_SERVER_VARS['SERVER_NAME']).str_replace('http://'.$HTTP_SERVER_VARS['SERVER_NAME'],'',$NWCONF_SYSTEM['domain_path']).$archiv_url;
  $key = 0;
  while ($mail_tpl[$key]) {
    $message .= $mail_tpl[$key++];
  }
  $message = str_replace('[--AUTHOR--]',$NW_FORMDATA['news_name'],$message);
  $message = str_replace('[--DATE--]',$NW_FORMDATA['news_date'],$message);
  $message = str_replace('[--TITLE--]',$NW_FORMDATA['news_title'],$message);
  $message = str_replace('[--TEXT--]',$NW_FORMDATA['news_text'],$message);
	$message = str_replace('[--TOPIC--]',$NW_FORMDATA['news_topic'],$message);
	$message = str_replace('[--SUBTOPIC--]',$NW_FORMDATA['news_subtopic'],$message);
	$message = str_replace('[--LINK--]',$link,$message);
  $file = fopen($NWCONF_SYSTEM['server_path'].$NWCONF_SYSTEM['data_dir'].'/emails.txt',"r");
          for ($i=0;$i<1000;$i++)
          {
                if (!feof($file))
                {
                    $zeile = fgets($file,100);
                    $zeile2 = chop($zeile);
                    $zeile3 = strtolower($zeile2);
                    $email2 = strtolower($email);
                    if ($email2 != $zeile3)
                    {
                         $speichern[$i] = $zeile2;
                         $z+=1;
                    }
                }
                if (feof($file))
                {
                    break;
                }
           }
           fclose($file);
           $i=0;
           for ($i=0;$i<$z;$i++)
           {
             @mail($speichern[$i],$NWCONF_NEWSLETTER['subject'], $message, 'From: '.$NWCONF_NEWSLETTER['send_from']);
           }
           echo "Die Nachricht wurde allen Empfngern des newsletters zu gesandt";
}
?>